pub struct DeleteTool { /* private fields */ }Expand description
Deletes a file or directory.
Tool name: fs.delete
For directories, set recursive to remove non-empty directories. The
missing_ok flag suppresses errors when the target does not exist.
Example
use agentkit_tool_fs::DeleteTool;
use agentkit_tools_core::Tool;
let tool = DeleteTool::default();
assert_eq!(&tool.spec().name.0, "fs.delete");Trait Implementations
Sourceimpl Clone for DeleteTool
impl Clone for DeleteTool
Sourcefn clone(&self) -> DeleteTool
fn clone(&self) -> DeleteTool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeleteTool
impl Debug for DeleteTool
Sourceimpl Default for DeleteTool
impl Default for DeleteTool
Sourceimpl Tool for DeleteTool
impl Tool for DeleteTool
Sourcefn proposed_requests(
&self,
request: &ToolRequest,
) -> Result<Vec<Box<dyn PermissionRequest>>, ToolError>
fn proposed_requests( &self, request: &ToolRequest, ) -> Result<Vec<Box<dyn PermissionRequest>>, ToolError>
Sourcefn invoke<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
request: ToolRequest,
ctx: &'life1 mut ToolContext<'life2>,
) -> Pin<Box<dyn Future<Output = Result<ToolResult, ToolError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn invoke<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
request: ToolRequest,
ctx: &'life1 mut ToolContext<'life2>,
) -> Pin<Box<dyn Future<Output = Result<ToolResult, ToolError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Executes the tool and returns a result or error. Read more