pub struct ReadFileTool { /* private fields */ }Expand description
Reads a UTF-8 text file, optionally limited to a 1-based inclusive line range.
Tool name: fs.read_file
When FileSystemToolResources is available in the tool context, a
successful read marks the path as inspected for the current session.
Example
use agentkit_tool_fs::ReadFileTool;
use agentkit_tools_core::Tool;
let tool = ReadFileTool::default();
assert_eq!(&tool.spec().name.0, "fs.read_file");Trait Implementations
Sourceimpl Clone for ReadFileTool
impl Clone for ReadFileTool
Sourcefn clone(&self) -> ReadFileTool
fn clone(&self) -> ReadFileTool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReadFileTool
impl Debug for ReadFileTool
Sourceimpl Default for ReadFileTool
impl Default for ReadFileTool
Sourceimpl Tool for ReadFileTool
impl Tool for ReadFileTool
Sourcefn proposed_requests(
&self,
request: &ToolRequest,
) -> Result<Vec<Box<dyn PermissionRequest>>, ToolError>
fn proposed_requests( &self, request: &ToolRequest, ) -> Result<Vec<Box<dyn PermissionRequest>>, ToolError>
Sourcefn invoke<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
request: ToolRequest,
ctx: &'life1 mut ToolContext<'life2>,
) -> Pin<Box<dyn Future<Output = Result<ToolResult, ToolError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn invoke<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
request: ToolRequest,
ctx: &'life1 mut ToolContext<'life2>,
) -> Pin<Box<dyn Future<Output = Result<ToolResult, ToolError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Executes the tool and returns a result or error. Read more